pub struct WalSourceState { /* private fields */ }Expand description
Transaction-aware converter from decoded WAL events to dataflow updates.
Implementations
Sourceimpl WalSourceState
impl WalSourceState
Sourcepub fn apply(&mut self, event: DecodedEvent) -> Vec<WalUpdate>
pub fn apply(&mut self, event: DecodedEvent) -> Vec<WalUpdate>
Applies a decoded WAL event and returns updates ready to enter dataflow.
Sourcepub fn apply_transaction(
&mut self,
event: DecodedEvent,
) -> Option<WalTransaction>
pub fn apply_transaction( &mut self, event: DecodedEvent, ) -> Option<WalTransaction>
Applies a decoded WAL event and returns a complete transaction at commit.