pub enum WorkerCommand {
Build(Box<dyn FnOnce(&mut LocalTimelyWorker) + Send + 'static>),
Step,
Stop,
}Expand description
Commands accepted by the embedded timely worker.
Variants
Build(Box<dyn FnOnce(&mut LocalTimelyWorker) + Send + 'static>)
Install or mutate dataflows on the timely worker.
Step
Drive the timely worker for a bounded number of scheduling steps.
Stop
Stop the worker task after queued commands already received are handled.