pub struct WorkerHandle { /* private fields */ }Expand description
Handle for an embedded timely worker running inside a tokio blocking task.
Implementations
Sourceimpl WorkerHandle
impl WorkerHandle
Sourcepub async fn build(
&self,
build: impl FnOnce(&mut LocalTimelyWorker) + Send + 'static,
) -> Result<(), WorkerError>
pub async fn build( &self, build: impl FnOnce(&mut LocalTimelyWorker) + Send + 'static, ) -> Result<(), WorkerError>
Applies a build closure inside the worker task.
Sourcepub async fn step(&self) -> Result<(), WorkerError>
pub async fn step(&self) -> Result<(), WorkerError>
Drives the timely worker for one bounded step tick.
Sourcepub async fn stop(self) -> Result<WorkerStats, WorkerError>
pub async fn stop(self) -> Result<WorkerStats, WorkerError>
Stops the worker and returns final loop statistics.